summaryrefslogtreecommitdiffstats
path: root/examples
diff options
context:
space:
mode:
authorDavid Faure <faure@kde.org>2011-10-22 11:33:06 +0200
committerQt by Nokia <qt-info@nokia.com>2011-10-23 15:28:25 +0200
commitdfa24768a3243eda68d91f573050bf23f96da2dd (patch)
tree40437c86c50a7ed1557caf8559129724899cd918 /examples
parent59f91c0194f1ac83ae78e4b22f466e25873e1282 (diff)
Deprecate QDesktopServices::storageLocation/displayName
Which required porting the related unittests to qstandardpaths Change-Id: I6eb63c46845f05cd29cc42b59872707526277c90 Reviewed-by: Thiago Macieira (Intel) <thiago.macieira@intel.com>
Diffstat (limited to 'examples')
-rw-r--r--examples/qtconcurrent/imagescaling/imagescaling.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/qtconcurrent/imagescaling/imagescaling.cpp b/examples/qtconcurrent/imagescaling/imagescaling.cpp
index 6ed7ae7511..fe2e3f4dad 100644
--- a/examples/qtconcurrent/imagescaling/imagescaling.cpp
+++ b/examples/qtconcurrent/imagescaling/imagescaling.cpp
@@ -100,9 +100,9 @@ void Images::open()
imageScaling->waitForFinished();
}
// Show a file open dialog at QDesktopServices::PicturesLocation.
QStringList files = QFileDialog::getOpenFileNames(this, tr("Select Images"),
- QDesktopServices::storageLocation(QDesktopServices::PicturesLocation),
+ QStandardPaths::writableLocation(QStandardPaths::PicturesLocation),
"*.jpg *.png");
if (files.count() == 0)
@@ -100,9 +100,9 @@ void Images::open()
imageScaling->waitForFinished();
}
- // Show a file open dialog at QDesktopServices::PicturesLocation.
+ // Show a file open dialog at QStandardPaths::PicturesLocation.
QStringList files = QFileDialog::getOpenFileNames(this, tr("Select Images"),